==> xcpcio_board_spider-0.0.43-py3-none-any.whl: xcpcio_board_spider/type/constants.py <==
RESULT_PENDING = "PENDING"
RESULT_WAITING = "WAITING"
RESULT_PREPARING = "PREPARING"
RESULT_COMPILING = "COMPILING"
RESULT_RUNNING = "RUNNING"
RESULT_JUDGING = "JUDGING"
RESULT_FROZEN = "FROZEN"

RESULT_ACCEPTED = "ACCEPTED"
RESULT_CORRECT = "CORRECT"
RESULT_PARTIALLY_CORRECT = "PARTIALLY_CORRECT"

RESULT_REJECTED = "REJECTED"
RESULT_WRONG_ANSWER = "WRONG_ANSWER"
RESULT_INCORRECT = "INCORRECT"

RESULT_COMPILATION_ERROR = "COMPILATION_ERROR"
RESULT_PRESENTATION_ERROR = "PRESENTATION_ERROR"

RESULT_RUNTIME_ERROR = "RUNTIME_ERROR"
RESULT_TIME_LIMIT_EXCEEDED = "TIME_LIMIT_EXCEEDED"
RESULT_MEMORY_LIMIT_EXCEEDED = "MEMORY_LIMIT_EXCEEDED"
RESULT_OUTPUT_LIMIT_EXCEEDED = "OUTPUT_LIMIT_EXCEEDED"
RESULT_IDLENESS_LIMIT_EXCEEDED = "IDLENESS_LIMIT_EXCEEDED"

RESULT_HACKED = "HACKED"

RESULT_JUDGEMENT_FAILED = "JUDGEMENT_FAILED"
RESULT_CONFIGURATION_ERROR = "CONFIGURATION_ERROR"
RESULT_FILE_ERROR = "FILE_ERROR"
RESULT_SYSTEM_ERROR = "SYSTEM_ERROR"
RESULT_CANCELED = "CANCELED"
RESULT_SKIPPED = "SKIPPED"

RESULT_SECURITY_VIOLATED = "SECURITY_VIOLATED"
RESULT_DENIAL_OF_JUDGEMENT = "DENIAL_OF_JUDGEMENT"

RESULT_UNKNOWN = "UNKNOWN"
RESULT_UNDEFINED = "UNDEFINED"

TEAM_TYPE_OFFICIAL = "official"
TEAM_TYPE_UNOFFICIAL = "unofficial"
TEAM_TYPE_GIRL = "girl"

TEAM_TYPE_ZH_CN_OFFICIAL = "正式队伍"
TEAM_TYPE_ZH_CH_UNOFFICIAL = "打星队伍"
TEAM_TYPE_ZH_CH_GIRL = "女队"

FULL_STATUS_TIME_DISPLAY = {
    RESULT_CORRECT.lower(): True,
    RESULT_INCORRECT.lower(): True,
    RESULT_PENDING.lower(): True,
}

CALCULATION_OF_PENALTY_IN_MINUTES = "in-minutes"
CALCULATION_OF_PENALTY_IN_SECONDS = "in-seconds"
CALCULATION_OF_PENALTY_ACCUMULATE_IN_SECONDS_AND_FINALLY_TO_THE_MINUTE = "accumulate-in-seconds-and-finally-to-the-minute"

==> xcpcio_board_spider-0.0.56-py3-none-any.whl: xcpcio_board_spider/type/constants.py <==
RESULT_PENDING = "PENDING"
RESULT_WAITING = "WAITING"
RESULT_PREPARING = "PREPARING"
RESULT_COMPILING = "COMPILING"
RESULT_RUNNING = "RUNNING"
RESULT_JUDGING = "JUDGING"
RESULT_FROZEN = "FROZEN"

RESULT_ACCEPTED = "ACCEPTED"
RESULT_CORRECT = "CORRECT"
RESULT_PARTIALLY_CORRECT = "PARTIALLY_CORRECT"

RESULT_REJECTED = "REJECTED"
RESULT_WRONG_ANSWER = "WRONG_ANSWER"
RESULT_INCORRECT = "INCORRECT"

RESULT_COMPILATION_ERROR = "COMPILATION_ERROR"
RESULT_PRESENTATION_ERROR = "PRESENTATION_ERROR"

RESULT_RUNTIME_ERROR = "RUNTIME_ERROR"
RESULT_TIME_LIMIT_EXCEEDED = "TIME_LIMIT_EXCEEDED"
RESULT_MEMORY_LIMIT_EXCEEDED = "MEMORY_LIMIT_EXCEEDED"
RESULT_OUTPUT_LIMIT_EXCEEDED = "OUTPUT_LIMIT_EXCEEDED"
RESULT_IDLENESS_LIMIT_EXCEEDED = "IDLENESS_LIMIT_EXCEEDED"

RESULT_HACKED = "HACKED"

RESULT_JUDGEMENT_FAILED = "JUDGEMENT_FAILED"
RESULT_CONFIGURATION_ERROR = "CONFIGURATION_ERROR"
RESULT_FILE_ERROR = "FILE_ERROR"
RESULT_SYSTEM_ERROR = "SYSTEM_ERROR"
RESULT_CANCELED = "CANCELED"
RESULT_SKIPPED = "SKIPPED"

RESULT_SECURITY_VIOLATED = "SECURITY_VIOLATED"
RESULT_DENIAL_OF_JUDGEMENT = "DENIAL_OF_JUDGEMENT"

RESULT_UNKNOWN = "UNKNOWN"
RESULT_UNDEFINED = "UNDEFINED"

TEAM_TYPE_OFFICIAL = "official"
TEAM_TYPE_UNOFFICIAL = "unofficial"
TEAM_TYPE_GIRL = "girl"

TEAM_TYPE_ZH_CN_OFFICIAL = "正式队伍"
TEAM_TYPE_ZH_CH_UNOFFICIAL = "打星队伍"
TEAM_TYPE_ZH_CH_GIRL = "女队"

FULL_STATUS_TIME_DISPLAY = {
    RESULT_CORRECT.lower(): True,
    RESULT_INCORRECT.lower(): True,
    RESULT_PENDING.lower(): True,
}

CALCULATION_OF_PENALTY_IN_MINUTES = "in_minutes"
CALCULATION_OF_PENALTY_IN_SECONDS = "in_seconds"
CALCULATION_OF_PENALTY_ACCUMULATE_IN_SECONDS_AND_FINALLY_TO_THE_MINUTE = "accumulate_in_seconds_and_finally_to_the_minute"

SUBMISSION_TIMESTAMP_UNIT_SECOND = "second"
SUBMISSION_TIMESTAMP_UNIT_MILLISECOND = "millisecond"
SUBMISSION_TIMESTAMP_MICROSECOND = "microsecond"
SUBMISSION_TIMESTAMP_NANOSECOND = "nanosecond"
